@@ -1,5 +1,7 @@
 from enum import Enum, unique
-from .util import Util
+
+from .action import Action
+from .stringifier import Stringifier
 
 
 class GoalMetadata:
@@ -23,10 +25,11 @@ class GoalMetadata:
         specific step.
         See StepMetadata.action_list for the available actions of the current
         step.
-        May be a subset of all possible actions. See [Actions](#Actions).
+        May be a subset of all possible actions. See
+        :mod:`Action <machine_common_sense.Action>`.
     category : string
         The category that describes this goal and the properties in its
-        metadata. See [Goals](#Goals).
+        metadata. See :mod:`Goal <machine_common_sense.GoalCategory>`.
     description : string
         A human-readable sentence describing this goal and containing
         the target task(s) and object(s).
@@ -47,7 +50,7 @@ class GoalMetadata:
         black, blue, brown, green, grey, orange, purple, red, white, yellow
 
         Materials:
-        See [Materials](#Materials).
+        See :mod:`Material <machine_common_sense.Material>`.
     habituation_total : int
         The total count of habituation trials that will be in this scene.
     last_preview_phase_step : integer
@@ -60,9 +63,12 @@ class GoalMetadata:
         The last step of this scene. This scene will automatically end
         following this step.
     metadata : dict
-        The metadata specific to this goal. See [Goals](#Goals).
+        The metadata specific to this goal. See
+        :mod:`Goal <machine_common_sense.GoalCategory>`.
     """
 
+    ACTION_LIST = [(item.value, {}) for item in Action]
+
     def __init__(
         self,
         action_list=None,
@@ -83,7 +89,7 @@ class GoalMetadata:
         self.metadata = {} if metadata is None else metadata
 
     def __str__(self):
-        return Util.class_to_str(self)
+        return Stringifier.class_to_str(self)
 
     # Allows converting the class to a dictionary, along with allowing
     #   certain fields to be left out of output file
@@ -98,6 +104,21 @@ class GoalMetadata:
         # yield 'type_list', self.type_list
         yield 'metadata', self.metadata
 
+    def retrieve_action_list_at_step(self, step_number):
+        """Return the action list from the given goal at the given step as a
+        a list of actions tuples by default."""
+        if self is not None and self.action_list is not None:
+            if step_number < self.last_preview_phase_step:
+                return ['Pass']
+            if self.last_step is not None and step_number == self.last_step:
+                return []
+            adjusted_step = step_number - self.last_preview_phase_step
+            if len(self.action_list) > adjusted_step:
+                if len(self.action_list[adjusted_step]) > 0:
+                    return self.action_list[adjusted_step]
+
+        return GoalMetadata.ACTION_LIST
+
 
 @unique
 class GoalCategory(Enum):
@@ -161,20 +182,12 @@ class GoalCategory(Enum):
     ----------
     target.id : string
         The objectId of the target object to retrieve.
-
-    target.image : list of numpy arrays
-        An image of the target object to retrieve, given as a 3D RGB pixel
-        array.
+        Will only be available at `oracle` metadata level.
 
     target.info : list of strings
         Human-readable information describing the target object needed for the
         visualization interface.
 
-    target.match_image : string
-        Whether the image of the target object (target.image) exactly matches
-        the actual target object in the scene. If false, then the actual object
-        will be different in one way (for example, the image may depict a blue
-        ball, but the actual object is a yellow ball, or a blue cube).
     """
 
     TRANSFERRAL = "transferral"
